==> fast-0.3.2.tar.gz: bin/fast.dart <==
//Copyright 2020 Pedro Bissonho
//
//Licensed under the Apache License, Version 2.0 (the "License");
//you may not use this file except in compliance with the License.
//You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
//Unless required by applicable law or agreed to in writing, software
//distributed under the License is distributed on an "AS IS" BASIS,
//WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//See the License for the specific language governing permissions and
//limitations under the License.

import 'package:args/command_runner.dart';
import 'package:fast/commands/flutter/install_package.dart';
import 'package:fast/commands/flutter/clear_command.dart';
import 'package:fast/commands/flutter/config_command.dart';
import 'package:fast/commands/flutter/create_flutter_comand.dart';
import 'package:fast/commands/flutter/run_command.dart';
import 'package:fast/commands/flutter/setup_command.dart';
import 'package:fast/commands/flutter/snippets_command.dart';
import 'package:fast/config_storage.dart';
import 'package:fast/fast.dart';

void main(List<String> arguments) async {
  var commandRunner = CommandRunner('Fast CLI', 'An incredible Dart CLI.');
  var storage = ConfigStorage();
  var fastzCLI = FastCLI(
    ConfigStorage(),
    commandRunner,
  );
  var isConfig = arguments.contains('config');
  await fastzCLI.setupCommandRunner(isConfig);
  fastzCLI.addCommands([
    FlutterCreaterComand(storage),
    ClearCommand(),
    SetupComand(),
    RunComand(),
    InstallPackageCommand(),
    ConfigCommand(),
    SnippetsCommand(),
  ]);
  await fastzCLI.run(arguments);
}

==> fast-0.4.0.tar.gz: bin/fast.dart <==
//Copyright 2020 Pedro Bissonho
//
//Licensed under the Apache License, Version 2.0 (the "License");
//you may not use this file except in compliance with the License.
//You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
//Unless required by applicable law or agreed to in writing, software
//distributed under the License is distributed on an "AS IS" BASIS,
//WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//See the License for the specific language governing permissions and
//limitations under the License.

import 'package:args/command_runner.dart';
import 'package:fast/commands/flutter/install_package.dart';
import 'package:fast/commands/flutter/clear_command.dart';
import 'package:fast/commands/plugin.dart';
import 'package:fast/config_storage.dart';
import 'package:fast/fast.dart';

void main(List<String> arguments) async {
  var commandRunner = CommandRunner('Fast CLI', 'An incredible Dart CLI.');
  var pluginStorage = PluginStorage();
  var fastzCLI = FastCLI(commandRunner, pluginStorage);
  bool isPlugin;
  if (arguments.isNotEmpty) {
    isPlugin = arguments.first == 'load_plugin';
  } else {
    isPlugin = false;
  }

  if (isPlugin) {
    final pluginName = arguments[1];
    await fastzCLI.setupCommandRunner(pluginName);
  } else {
    await fastzCLI.addCommands([
      ClearCommand(),
      InstallPackageCommand(),
      PluginCommand(pluginStorage)
    ]);
  }

  await fastzCLI.run(arguments, isPlugin);
}
